@@ -1,5 +1,5 @@
 package Cpanel::JSON::XS;
-our $VERSION = '3.0221';
+our $VERSION = '3.0222';
 our $XS_VERSION = $VERSION;
 $VERSION = eval $VERSION;
 
@@ -178,16 +178,17 @@ B<Changes to JSON::XS>
   production module, just during development and testing.
 
 - extended testsuite, passes all http://seriot.ch/parsing_json.html tests.
-  It just cannot handle UTF16 nor UTF32 BOM yet.
   In fact it is the only know JSON decoder which does so, while being the fastest.
 
 - support many more options and methods from JSON::PP:
   stringify_infnan, allow_unknown, allow_stringify, allow_barekey,
   encode_stringify, allow_bignum, allow_singlequote, sort_by (partially),
   escape_slash, convert_blessed, ...
-
   optional decode_json(, allow_nonref) arg
 
+- support all 5 unicode BOM's: UTF-8, UTF-16LE, UTF-16BE, UTF-32LE, UTF-32BE,
+  encoding internally to UTF-8.
+
 =cut
 
 our @ISA = qw(Exporter);
@@ -1293,7 +1294,26 @@ This is a complex example, but most of the complexity comes from the fact
 that we are trying to be correct (bear with me if I am wrong, I never ran
 the above example :).
 
+=head1 BOM
 
+Detect all unicode B<Byte Order Marks> on decode.
+Which are UTF-8, UTF-16LE, UTF-16BE, UTF-32LE and UTF-32BE.
+
+B<Warning>: With perls older than 5.20 you need load the Encode module
+before loading a multibyte BOM, i.e. >= UTF-16. Otherwise an error is
+thrown. This is an implementation limitation and might get fixed later.
+
+See L<https://tools.ietf.org/html/rfc7159#section-8.1>
+I<"JSON text SHALL be encoded in UTF-8, UTF-16, or UTF-32.">
+
+I<"Implementations MUST NOT add a byte order mark to the beginning of a
+JSON text", "implementations (...) MAY ignore the presence of a byte
+order mark rather than treating it as an error".>
+
+See also L<http://www.unicode.org/faq/utf_bom.html#BOM>.
+
+Beware that Cpanel::JSON::XS is currently the only JSON module which does accept
+and decode a BOM.
 
 =head1 MAPPING
 
@@ -1899,8 +1919,7 @@ output (modulo bugs, but C<JSON::XS> has found more bugs in the
 official JSON testsuite (1) than the official JSON testsuite has found
 in C<JSON::XS> (0)).
 C<Cpanel::JSON::XS> is currently the only known JSON decoder which passes all
-L<http://seriot.ch/parsing_json.html> tests (well, all but the BOM tests),
-while being the fastest also.
+L<http://seriot.ch/parsing_json.html> tests, while being the fastest also.
 
 When you have trouble decoding JSON generated by this module using other
 decoders, then it is very likely that you have an encoding mismatch or the
